@@ -23,7 +23,7 @@ from tqdm import tqdm
 __author__ = "mondeja"
 __description__ = "Multiplatform Blender portable release downloader script."
 __title__ = "blender-downloader"
-__version__ = "0.0.23"
+__version__ = "0.1.0"
 
 QUIET = False
 
@@ -746,10 +746,12 @@ def download_release(download_url, output_directory, quiet=False):
         chunksize = 8192
         downloaded_size = chunksize
         res = urlopen(Request(download_url))
-        total_size_bits = int(res.info()["Content-Length"])
+        total_size_bytes = int(res.info()["Content-Length"])
+
+        _verify_disk_space(output_directory, total_size_bytes)
 
         progress_bar_kwargs = dict(
-            total=total_size_bits,
+            total=total_size_bytes,
             unit="B",
             desc=f"Downloading '{output_filename}'",
             unit_scale=True,
@@ -768,7 +770,7 @@ def download_release(download_url, output_directory, quiet=False):
                 f.write(data)
                 progress_bar.update(chunksize)
                 downloaded_size += chunksize
-                if downloaded_size >= total_size_bits:
+                if downloaded_size >= total_size_bytes:
                     break
     except KeyboardInterrupt:
         sys.stderr.write("Download interrupted\n")
@@ -786,6 +788,17 @@ def download_release(download_url, output_directory, quiet=False):
     return output_filepath
 
 
+def _verify_disk_space(output_dir, total_size):
+    free_space = shutil.disk_usage(output_dir).free
+    if free_space < total_size:
+        sys.stderr.write(
+            f"Not enough free space at {output_dir}."
+            f" Free space: {free_space} bytes."
+            f" Needed: {total_size} bytes."
+        )
+        sys.exit(1)
+
+
 def extract_release(zipped_filepath, quiet=False):
     """Extracts, if needed, a Blender release file depending on their file type.
 
@@ -1126,7 +1139,7 @@ def list_available_blender_versions(
         "nightly",
         use_cache=use_cache,
     )
-    sys.stdout.write(f"{nightly_version}\n")
+    sys.stdout.write(f"{nightly_version} (latest)\n")
     versions_found.append(nightly_version)
     n_versions += 1
     if maximum_versions < 2:
@@ -1139,7 +1152,7 @@ def list_available_blender_versions(
     )
     versions_found.append(stable_version)
     if maximum_versions < 3:
-        sys.stdout.write(f"{stable_version}\n")
+        sys.stdout.write(f"{stable_version} (stable)\n")
         return 0
     stable_Version = BlenderVersion(stable_version)
     _stable_version_printed = False
@@ -1212,15 +1225,13 @@ def list_available_blender_versions(
 
             # print version
             #   print stable version in their correct place
-            if BlenderVersion(version) < stable_Version and not _stable_version_printed:
-                n_versions += 1
-                sys.stdout.write(f"{stable_version}\n")
+            if not _stable_version_printed and BlenderVersion(version) < stable_Version:
+                sys.stdout.write(f"{stable_version} (stable)\n")
                 _stable_version_printed = True
-                if n_versions >= maximum_versions:
-                    break
+            else:
+                sys.stdout.write(f"{version}\n")
 
             versions_found.append(version)
-            sys.stdout.write(f"{version}\n")
             n_versions += 1
 
             if n_versions >= maximum_versions:
